FUNCTION vs_baseproj, OD, StartHr, EndHr, BaseLine, NumBlines, Lambda, Isize
; Arguments: 
; object declination (Degrees), start hour, end hour
; baselines array, number of baselines, wavelength (metres), image
; size
;
  ;;
  ;; Basic data
  ;;
  LatParanal = ten(-24, 37, 30) ; Paranal Latitude
  CoLat = (90.-LatParanal)*!pi/180. ; Counted from southpole...
  ObjDec = OD*!pi/180. ;Object Declination
  JVec = indgen(Isize)          ; Help vector to avoid loops
  BaseTrack = fltarr(NumBlines, Isize, 3) ; To hold the result
                                ;0 holds east coordinate
                                ;1 holds north coordinate
                                ;2 holds time stamp
  ;;
  ;; UT coordinates (Metres from UT1)
  ;;
  UT = [[0., 0., 0.], $         ; UT1
        [30., 30., 0.], $       ; UT2
        [70., 64., 0.], $       ; UT3
        [128., 24., 0.]]        ; UT4
  VLTrot = 19.55*!dtor          ; Rotation of telescope coordinates against north
  RotMatrix = [[cos(VLTrot), -sin(VLTrot)], $
               [sin(VLTrot), cos(VLTrot)]]
  FOR i=0, 3 DO UT[0:1, i] = RotMatrix##UT[0:1, i] ; Rotate the VLTI...
  ;;
  ;; Calculation of Baseline Coordinates
  ;;
  BaseLineCoordinates = fltarr(3, NumBlines)
  BaseLineCoordinates[0, *] = UT[0, BaseLine[0, *]] -  UT[0, BaseLine[1, *]]
  BaseLineCoordinates[1, *] = UT[1, BaseLine[0, *]] -  UT[1, BaseLine[1, *]]
  BaseLineCoordinates[2, *] = UT[2, BaseLine[0, *]] -  UT[2, BaseLine[1, *]]
  ;;
  ;; Now turn them into UV Tracks
  ;;
  hh = float(StartHr)+(float(EndHr)-float(StartHr))*(float(JVec)/(Isize-1)) ;make steps for hourangle
  h = (15.*!pi/180.)*hh          ; Convert to radians
  FOR i=0, NumBlines-1 DO BEGIN ; For all baselines
      ;; Project baselines into sky plane
      R0 = (-BaseLineCoordinates[0, i]*cos(CoLat)+$ ;; North-South Projection
            BaseLineCoordinates[2, i]*sin(colat))
      R1 = BaseLineCoordinates[1, i]                ;; Nothing to project in East-West
      R2 = (BaseLineCoordinates[0, i]*sin(CoLat) +$ ;; Altitude Projection
            BaseLineCoordinates[2, i]*cos(CoLat))
      East = (R0*sin(h)+R1*cos(h))                  ;; Now compute east-west length for hourangles
      North = (-R0*sin(ObjDec)*cos(h)+$             ;; Same for north-south
               R1*sin(ObjDec)*sin(h)+$
               R2*cos(ObjDec))
      BaseTrack[i, JVec, 0] = -East/Lambda*4.84814e-6    ;; Convert the results to seconds of arc
      BaseTrack[i, JVec, 1] = North/Lambda*4.84814e-6
      BaseTrack[i, JVec, 2] = hh
  ENDFOR   
  ;;
  ;; Now return the result and finish!
  ;;
  return, BaseTrack
END 
