PRO vs_simmidi, state
  COMMON vs_block
  IF NOT vs_debug THEN on_error, 2 ;return to caller on error (if not in debugging mode)
  ;;
  ;; Basic Data
  ;;
  mJy4p4 = 390
  mJy10 = 890                   ;Janskys required for SNR 10
  BaseInt1 = 0.005              ;Basic integration time
  BaseInt2 = 0.025              ;Basic integration time
  NumBlines = state.NumBlines
  BaseLine = state.BaseLine
  BarID = vs_progbar(0, 0, Action='Reading Input File')
  ;;
  ;; Read Input File
  ;;
  Cube = readfits(state.InFile, CHead)
  IF total(Cube) EQ -1 THEN BEGIN
      vs_info, 'File '+state.InFile+' not found!', 4
      Dummy = VS_Progbar(BarID, -1)
      return
  ENDIF 
  NumAxis = sxpar(CHead, 'NAXIS')
  Isize = sxpar(CHead, 'NAXIS1')
  Ysize = sxpar(CHead, 'NAXIS2')
  unit = strcompress(sxpar(CHead, 'CALUNIT'), /remove)
  IF Isize NE Ysize THEN BEGIN
      vs_info, 'Can only work on square images', 2
       Dummy = VS_Progbar(BarID, -1)
      return
  ENDIF 
  IF unit EQ 'JY/PIX' THEN uFactor = 1e-3 ELSE BEGIN
      IF unit EQ 'mJY/PIX' THEN $
        uFactor = 1.0 $
      ELSE BEGIN 
          vs_info, 'Unknown unit: '+unit+'. Treating as mJy/Pix!', 3
          uFactor = 1.0
          
          ;Dummy = VS_Progbar(BarID, -1)
          ;return
      ENDELSE 
  ENDELSE 
  JVec = findgen(Isize)
  IF NumAxis GT 2 THEN $
    NumFrames=sxpar(CHead, 'NAXIS3') $
  ELSE $
    NumFrames=1
  PixSize = sxpar(CHead, 'PIXSIZE')
  Lambda = fltarr(NumFrames)    ; Now extract wavelengths & comments
  Comment = strarr(NumFrames)
  FOR i=0, NumFrames-1 DO BEGIN
      IF vs_debug THEN print, strcompress('LAMBDA'+string(format='(i3)', i+1), /rem)
      IF vs_debug THEN print, strcompress('TAG'+string(format='(i3)', i+1), /rem)
      lambda[i] = sxpar(CHead, strcompress('LAMBDA'+string(format='(i3)', i+1), /rem))
      TagTmp = sxpar(CHead, strcompress('TAG'+string(format='(i3)', i+1), /rem))
      IF !ERR NE -1 THEN Comment[i] =  TagTmp
  ENDFOR 
  ;;
  ;; check for need of external fringe tracking
  ;;
;  AirySize = Lambda/8.0*!Radeg*3600. ;Size of airy disk in arcsec
  AirySize = 1.0 ; use 1 arcsecond radius of field of view!
  ;;
  TrackerNeeded = intarr(N_Elements(Lambda)) ; make need vector
  TotFlux = fltarr(N_Elements(Lambda))
;  TotFlux = fltarr(N_Elements(Lambda))
  FOR i = 0, N_Elements(Lambda)-1 DO BEGIN
      Dist_Circle, Aperture, [ISize, YSize], ISize/2, YSize/2
      Aperture = Aperture*PixSize
      Outside = where(Aperture GT AirySize/2)
      Inside = where(Aperture LE AirySize/2)
      IF total(Outside) NE -1 THEN $
        Aperture[Outside] = 0.
      IF total(Inside) NE -1 THEN $
        Aperture[Inside] = 1.0
      TotFlux[i] = total(Aperture*Cube[*, *, i]*UFactor)
      TrackerNeeded[i] = 0
      
      IF TotFlux[i] LT mJy4p4+4*mJy4p4*(state.DIT EQ BaseInt1) THEN $ ; if 5ms,  5 times signal needed
        TrackerNeeded[i] = 1    ; if flux less then limit,  fringe tracking is needed
  ENDFOR 
  ;;
  ;; Compute visibilities
  ;;
  Dummy = VS_Progbar(BarID, 25, Action='Computing Visibilities...')
  Visib = fltarr(Isize, Isize, NumFrames)
  FOR i=0, NumFrames-1 DO BEGIN
      FT = fft(Cube[*, *, i], -1) ;fourier transform 
      Visi = shift(abs(FT)/abs(FT[0, 0]), Isize/2., Isize/2.) ;normalize and shift visibility
      IF state.Rot NE 0 THEN BEGIN
          Cube[*, *, i] = rot(Cube[*, *, i], state.Rot)
          Visi = rot(Visi, state.rot, cubic=-0.5)
      ENDIF 
      Visib[*, *, i] = Visi 
  ENDFOR 
  ;;
  ;; Compute baseline tracks
  ;;
  Dummy = VS_Progbar(BarID, 50, Action='Computing Baseline Tracks...')
  BaseTracks = fltarr(NumBlines, Isize, 3, NumFrames)
  IndTracks =  fltarr(NumBlines, Isize, 2, NumFrames)
  FOR i=0, NumFrames-1 DO BEGIN 
      BT = vs_baseproj(state.ObjDec, $
                       state.StartHr, $
                       state.EndHr, $
                       *state.BaseLine, $
                       state.NumBlines, $
                       lambda[i], $
                       Isize)
      BaseTracks[*, *, *, i] = BT
      IndTracks[*, *, 0:1, i] = BaseTracks[*, *, 0:1, i]*Isize*PixSize+Isize/2
  ENDFOR 
  ;;
  ;; Now make hourangle-freequency-visibility array
  ;;
  Dummy = VS_Progbar(BarID, 75, Action='Computing Result Array...')
  HFV = fltarr(NumBlines, Isize, 4, NumFrames)
  IF state.FilterW EQ 0 THEN BEGIN
      ;; simple case with infinite spectral resolution
      FOR i=0, NumFrames-1 DO BEGIN
          
          FOR j=0, NumBlines-1 DO BEGIN 
              HFV[j, *, 0, i] = BaseTracks[j, *, 2, i]
              HFV[j, *, 1, i] = sqrt(BaseTracks[j, *, 0, i]^2+BaseTracks[j, *, 1, i]^2)
              HFV[j, *, 2, i] = interpolate(Visib[*, *, i], $
                                            IndTracks[j, JVec, 0, i], $
                                            IndTracks[j, JVec, 1, i])
              vs_snr, state, TotFlux[i]*HFV[j, *, 2, i], Lambda[i], snr
              HFV[j, *, 3, i] = HFV[j, *, 2, i]/snr
          ENDFOR 
      ENDFOR 
  ENDIF ELSE BEGIN
      ;; Complicated case with averaging over 10 wavelengths
      NumSub = 10
      SubTracks = fltarr(NumBlines, Isize, 3, NumFrames, NumSub)
      SubIndTracks =  fltarr(NumBlines, Isize, 2, NumFrames, NumSub)
      FOR i=0, NumFrames-1 DO BEGIN ;Compute baseline tracks for sub-wavelengths
          SubLambdas = findgen(11)/10.*Lambda[i]*state.FilterW+Lambda[i]-Lambda[i]*state.FilterW/2
          IF vs_debug THEN print, 'Using Wavelengths: ', SubLambdas
          FOR j=0, NumSub-1 DO BEGIN 
              BT = vs_baseproj(state.ObjDec, $
                               state.StartHr, $
                               state.EndHr, $
                               *state.BaseLine, $
                               state.NumBlines, $
                               SubLambdas[j], $
                               Isize)
              SubTracks[*, *, *, i, j] = BT
              SubIndTracks[*, *, 0:1, i, j] = SubTracks[*, *, 0:1, i, j]*Isize*PixSize+Isize/2
          ENDFOR 
      ENDFOR 
      FOR i=0, NumFrames-1 DO BEGIN
          
          FOR j=0, NumBlines-1 DO BEGIN 
              HFV[j, *, 0, i] = BaseTracks[j, *, 2, i]
              HFV[j, *, 1, i] = sqrt(BaseTracks[j, *, 0, i]^2+BaseTracks[j, *, 1, i]^2)
              HelpVisi = fltarr(Isize, NumSub)
              FOR k=0, NumSub-1 DO BEGIN ;read visibilities along all sub-tracks
                  HelpVisi[*, k] = interpolate(Visib[*, *, i], $
                                               SubIndTracks[j, JVec, 0, i, k], $
                                               SubIndTracks[j, JVec, 1, i, k])
              ENDFOR 
              HFV[j, *, 2, i] = total(HelpVisi, 2)/NumSub ;average all sub-visibilities
              vs_snr, state, TotFlux[i]*HFV[j, *, 2, i], Lambda[i], snr
              HFV[j, *, 3, i] = HFV[j, *, 2, i]/snr
          ENDFOR 
      ENDFOR 
  ENDELSE 
  ;;
  ;; Store away result
  ;;
  state.Result = ptr_new({Cube:Cube, $
                          Visib:Visib, $
                          BaseTracks:BaseTracks, $
                          IndTracks:IndTracks, $
                          HFV:HFV, $
                          PixSize:PixSize, $
                          Lambda:Lambda, $
                          Comment:Comment, $
                          UseTrack:TrackerNeeded $
                         })
  ;;
  ;; Finished
  ;;
  state.ComputationDone = 1
  Dummy = VS_Progbar(BarID, -1)
END 
